@@ -1,4 +1,4 @@
-/* Copyright (C) 2001 to 2014 Chris Vine
+/* Copyright (C) 2001 to 2014 and 2020 Chris Vine
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -304,7 +304,7 @@ GplDialog::GplDialog(int size): WinBase(gettext("efax-gtk: Conditions, Notices a
   gtk_text_view_set_editable(text_view_p, false);
 
   PangoFontDescription* font_description = 
-    pango_font_description_from_string(prog_config.fixed_font.c_str());
+    pango_font_description_from_string("Mono");
 #if GTK_CHECK_VERSION(2,99,0)
   gtk_widget_override_font(GTK_WIDGET(text_view_p), font_description);
 #else
@@ -513,7 +513,7 @@ AboutEfaxGtkDialog::AboutEfaxGtkDialog(GtkWindow* parent_p, bool modal):
   gtk_about_dialog_set_program_name(GTK_ABOUT_DIALOG(get_win()), "efax-gtk");
   gtk_about_dialog_set_version(GTK_ABOUT_DIALOG(get_win()), VERSION);
   gtk_about_dialog_set_copyright(GTK_ABOUT_DIALOG(get_win()),
-				 gettext("Copyright (C) 2001 - 2014 Chris Vine"));
+				 gettext("Copyright (C) 2001 - 2020 Chris Vine"));
   gtk_about_dialog_set_license(GTK_ABOUT_DIALOG(get_win()),
 			       gpl_copyright_msg()->c_str()); // this function calls g_strdup()
   gtk_about_dialog_set_comments(GTK_ABOUT_DIALOG(get_win()),
