@@ -1,4 +1,4 @@
-/* Copyright (C) 2001 to 2005, 2010 and 2011 Chris Vine
+/* Copyright (C) 2001 to 2005, 2010, 2011 and 2020 Chris Vine
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -160,7 +160,7 @@ GtkWidget* HelpDialog::make_text_view(const char* text) {
   gtk_text_view_set_wrap_mode(text_view_p, GTK_WRAP_WORD);
   gtk_text_view_set_editable(text_view_p, false);
   PangoFontDescription* font_description = 
-    pango_font_description_from_string(prog_config.fixed_font.c_str());
+    pango_font_description_from_string("Mono");
 #if GTK_CHECK_VERSION(2,99,0)
   gtk_widget_override_font(GTK_WIDGET(text_view_p), font_description);
 #else
