@@ -1,4 +1,4 @@
-/* Copyright (C) 2001 to 2014 Chris Vine
+/* Copyright (C) 2001 to 2014 and 2020 Chris Vine
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -56,15 +56,6 @@
 #include "utils/icon_info_handle.h"
 #include "utils/utf8_utils.h"
 
-#ifdef HAVE_X11_XLIB_H
-#include <X11/Xlib.h>
-#include <gdk/gdkx.h>  // for GDK_DISPLAY_XDISPLAY()
-#endif
-
-#ifdef HAVE_X11_XKBLIB_H
-#include <X11/XKBlib.h>  // for beep
-#endif
-
 #include <c++-gtk-utils/mutex.h>
 #include <c++-gtk-utils/gobj_handle.h>
 #include <c++-gtk-utils/pipes.h>
@@ -87,7 +78,6 @@ extern "C" pid_t getpgid(pid_t);
 
 Prog_config prog_config;
 
-void get_fonts(void);
 void get_window_icon(void);
 int mkdir_with_parent(const std::string&);
 bool is_arg(const char*, int, char*[]);
@@ -142,7 +132,7 @@ int main(int argc, char* argv[]) {
   if (argc > 1) {
     if (is_arg("--version", argc, argv)) {
       std::string message("efax-gtk-" VERSION "\n");
-      message += gettext("Copyright (C) 2001 - 2014 Chris Vine\n"
+      message += gettext("Copyright (C) 2001 - 2020 Chris Vine\n"
 			 "This program is released under the "
 			 "GNU General Public License, version 2\n");
       try {
@@ -201,8 +191,6 @@ int main(int argc, char* argv[]) {
       std::exit(PIPE_ERROR);
     }
 
-    get_fonts();
-
     get_window_icon();
 
     if (!prog_config.GPL_flag) {
@@ -880,40 +868,6 @@ std::string configure_prog(bool reread) {
   return return_val;
 }
 
-void get_fonts(void) {
-
-#ifdef HAVE_X11_XLIB_H
-  // this will get a suitable fixed font for GplDialog and HelpDialog to use with Pango
-  const int MAX_FONTS = 10000;
-  int num_fonts;
-  char** fonts = XListFonts(GDK_DISPLAY_XDISPLAY(gdk_display_get_default()), "-*", MAX_FONTS, &num_fonts);
-
-  if (fonts) {
-    int count;
-    std::string inspect_name;
-    prog_config.fixed_font = "";
-
-    //try for courier font
-    for (count = 0; count < num_fonts; count++) {
-      inspect_name = fonts[count];
-      std::string::size_type pos = inspect_name.find("courier-medium-r-normal-");
-      if (pos != std::string::npos) {
-	prog_config.fixed_font = "courier";
-	break;
-      }
-    }
-
-    // unsuccessful -- go for the generic "fixed" font
-    if (prog_config.fixed_font.empty()) prog_config.fixed_font = "fixed";
-
-    XFreeFontNames(fonts);
-  }
-  else prog_config.fixed_font = "fixed";
-#else
-  prog_config.fixed_font = "fixed";
-#endif
-}
-
 bool get_prog_parm(const char* name, std::string& line, std::string& result,
 		   std::string(*convert_func)(const std::string&)) {
 // This function looks for a setting named `name' in the string `line'
@@ -951,13 +905,7 @@ bool get_prog_parm(const char* name, std::string& line, std::string& result,
 }
 
 void beep(void) {
-#if defined(HAVE_X11_XKBLIB_H) && defined(HAVE_X11_XLIB_H)
-  XkbBell(GDK_DISPLAY_XDISPLAY(gdk_display_get_default()), None, 0, None);
-#elif defined(HAVE_X11_XLIB_H)
-  XBell(GDK_DISPLAY_XDISPLAY(gdk_display_get_default()), 0);
-#else
   gdk_beep();
-#endif
 }
 
 void get_window_icon(void) {
