@@ -1,4 +1,4 @@
-/* Copyright (C) 2001 to 2013 Chris Vine
+/* Copyright (C) 2001 to 2013 and 2020 Chris Vine
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -59,10 +59,6 @@
 #include <c++-gtk-utils/io_watch.h>
 #include <c++-gtk-utils/timeout.h>
 
-#ifdef HAVE_X11_XLIB_H
-#include <gdk/gdkx.h>
-#endif
-
 #ifdef HAVE_STREAM_IMBUE
 #include <locale>
 #endif
@@ -1688,8 +1684,7 @@ void MainWindow::tray_icon_activated_cb(void) {
     gtk_widget_hide(mainwin_p);
   }
 #endif
-  //else gtk_window_present(get_win());
-  else present_window();
+  else gtk_window_present(get_win());
 }
 
 void MainWindow::tray_icon_menu_cb(int item) {
@@ -1910,25 +1905,7 @@ void MainWindow::strip(std::string& text) {
 }
 
 void MainWindow::present_window(void) {
-
-  GtkWidget* main_widget_p = GTK_WIDGET(get_win());
-
-  // make sure the window is on the current workspace
-  // (gtk_window_present() should but won't do this)
-#ifdef HAVE_X11_XLIB_H
-# if GTK_CHECK_VERSION(2,14,0)
-  gdk_x11_window_move_to_current_desktop(gtk_widget_get_window(main_widget_p));
-# else
-  gdk_x11_window_move_to_current_desktop(main_widget_p->window);
-# endif
-#endif
-
-  // a call to gtk_window_present() now should be enough, but the calls to
-  // gtk_widget_hide() and gtk_window_deiconify() will get metacity to
-  // behave reasonably (shifting workspaces seems to confuse it)
-  gtk_widget_hide(main_widget_p);
   gtk_window_present(get_win());
-  gtk_window_deiconify(get_win());
 }
 
 void MainWindow::read_error_pipe_cb(bool&) {
