@@ -144,6 +144,9 @@ bool SocketServer::make_ipv4_socket(void) {
     socket_error_notify();
     return false;
   }
+  int optval = 1;
+  // we don't need to check the return value of setsockopt() here
+  setsockopt(serve_sock_fd, SOL_SOCKET, SO_REUSEADDR, &optval, sizeof(optval));
 
   sockaddr_in serve_address;
   std::memset(&serve_address, 0, sizeof(serve_address));
@@ -181,6 +184,9 @@ bool SocketServer::make_ipv6_socket(void) {
     socket_error_notify();
     return false;
   }
+  int optval = 1;
+  // we don't need to check the return value of setsockopt() here
+  setsockopt(serve_sock_fd, SOL_SOCKET, SO_REUSEADDR, &optval, sizeof(optval));
 
   sockaddr_in6 serve_address;
   std::memset(&serve_address, 0, sizeof(serve_address));
